@@ -2,7 +2,7 @@ from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
 from django.utils.translation import ugettext_lazy as _
 
-from django_user_email_extension.models import DjangoEmailVerifier, User, Address, PhoneNumber
+from django_user_email_extension.models import DjangoEmailVerifier, User, Address, UserPhoneNumber
 
 
 @admin.register(User)
@@ -10,7 +10,7 @@ class UserAdmin(UserAdmin):
     fieldsets = (
         (None, {'fields': ('email', 'password')}),
         (_('Personal info'),
-         {'fields': ('first_name', 'last_name', 'gender', 'birth_date', 'default_phone_number', 'language')}),
+         {'fields': ('first_name', 'last_name', 'gender', 'birth_date', 'language')}),
         (_('Address info'), {'fields': ['address']}),
         (_('Social info'), {'fields': ('linkedin', 'facebook', 'github', 'twitter')}),
         (_('Permissions'), {'fields': ('is_active', 'is_staff', 'is_superuser', 'groups', 'user_permissions')}),
@@ -24,6 +24,7 @@ class UserAdmin(UserAdmin):
     list_display = ('email', 'first_name', 'last_name', 'is_active', 'is_staff')
     search_fields = ('email', 'first_name', 'last_name')
     ordering = ('email',)
+    readonly_fields = ('date_created', 'last_update_date')
     pass
 
 
@@ -40,13 +41,15 @@ class UserAdmin(admin.ModelAdmin):
     list_display = ('street_name', 'street_number', 'city', 'state', 'country', 'zip_code')
     list_filter = ('country',)
     ordering = ('country', 'city', 'street_name',)
+    readonly_fields = ('created_at',)
     pass
 
 
-@admin.register(PhoneNumber)
+@admin.register(UserPhoneNumber)
 class UserAdmin(admin.ModelAdmin):
-    list_display = ('number', 'type', 'verified', 'belongs_to',)
-    list_filter = ('type', 'verified',)
-    search_fields = ('number', 'belongs_to',)
+    list_display = ('number', 'owner', 'verified', 'is_default')
+    list_filter = ('number', 'owner', 'verified', 'is_default')
+    search_fields = ('number', 'owner',)
     ordering = ('number',)
+    readonly_fields = ('created_at', 'verified_status_updated_at',)
     pass
