@@ -1,17 +1,19 @@
 import uuid
-from datetime import timedelta
+from datetime import timedelta, datetime, timezone
 
 import pytz
 from django.conf import settings
 from django.contrib.auth.models import BaseUserManager, AbstractBaseUser, PermissionsMixin
 from django.core.mail import send_mail
+from django.core.validators import validate_email
 from django.db import models
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
 from django_countries.fields import CountryField
 from phonenumber_field.modelfields import PhoneNumberField
+
 from django_user_email_extension.languages import LANGUAGES
-from django_user_email_extension.validators import validate_users_min_age
+from django_user_email_extension.validators import validate_users_min_age, validate_alphabetic_string
 
 
 class Address(models.Model):
@@ -27,6 +29,8 @@ class Address(models.Model):
     zip_code = models.IntegerField()
     timezone = models.CharField(max_length=32, choices=TIMEZONES, default='UTC')
 
+    created_at = models.DateTimeField(_('Date Created'), auto_now_add=True, blank=True, editable=False)
+
     class Meta:
         unique_together = (('street_name', 'street_number', 'city', 'state', 'country'),)  # Set primary combined key
         verbose_name = _('address')
@@ -56,7 +60,7 @@ class PhoneNumberManager(models.Manager):
         :param user: User object
         :return: QuerySet of PhoneNumber object, or empty
         """
-        return self.all().filter(belongs_to=user)
+        return self.all().filter(owner=user)
 
     def get_verified_phone_numbers_of_user(self, user):
         """
@@ -64,7 +68,7 @@ class PhoneNumberManager(models.Manager):
         :param user: User object
         :return: QuerySet of PhoneNumber object(s), or empty
         """
-        return self.all().filter(belongs_to=user, verified=True)
+        return self.all().filter(owner=user, verified=True)
 
     def get_verified_number_list(self, user):
         """
@@ -80,38 +84,67 @@ class PhoneNumberManager(models.Manager):
         return result
 
 
-class PhoneNumber(models.Model):
-    NUMBER_TYPES_CHOICES = (
-        ('m', 'Mobile'),
-        ('w', 'Work'),
-        ('h', 'Home'),
-        ('c', 'Car'),
-    )
-
-    # number = models.CharField(primary_key=True, validators=[phone_number_validator()], max_length=17)
-
+class UserPhoneNumber(models.Model):
     # uses https://github.com/stefanfoulis/django-phonenumber-field
-    number = PhoneNumberField(primary_key=True)
-    type = models.CharField(
-        _('Phone type'),
-        choices=NUMBER_TYPES_CHOICES, max_length=1, default='m')
+    number = PhoneNumberField()
+
     verified = models.BooleanField(
         _('Verified Status'),
         default=False,
-        help_text=_('Define if this number have been verified (belongs to user). '),
+        help_text=_('Define if this number have been verified.'),
     )
-    belongs_to = models.ForeignKey(settings.AUTH_USER_MODEL,
-                                   related_name='phone_number_obj',
-                                   on_delete=models.CASCADE,
-                                   null=True,
-                                   blank=True)
+    __original_verified = None
+    is_default = models.BooleanField(
+        _('Default Status'),
+        default=False,
+        help_text=_('Define if this number is users default number.'),
+    )
+    owner = models.ForeignKey(settings.AUTH_USER_MODEL,
+                              related_name='phone_number_obj',
+                              on_delete=models.CASCADE)
+    created_at = models.DateTimeField(_('Date Created'), auto_now_add=True, null=True, blank=True)
+    verified_status_updated_at = models.DateTimeField(null=True, editable=False)
 
     objects = PhoneNumberManager()
 
     class Meta:
-        verbose_name = _('Phone Number')
-        verbose_name_plural = _('Phone Number')
-        db_table = 'phone_number'
+        db_table = 'user_phone_numbers'
+        constraints = [
+            models.UniqueConstraint(fields=['number', 'owner'], name='unique_users_phone_number')
+        ]
+        verbose_name = _('User Phone Numbers')
+        verbose_name_plural = _('User Phone Numbers')
+
+    def __init__(self, *args, **kwargs):
+        super(UserPhoneNumber, self).__init__(*args, **kwargs)
+        self.__original_verified = self.verified
+
+    def save(self, *args, **kwargs):
+        # check if there is a change is the verified field
+        if self.verified != self.__original_verified:
+            # update timestamp
+            self.verified_status_updated_at = datetime.now(tz=timezone.utc)
+
+        # check there is no other same number(s) (from another owner) which are also verified,
+        # if there are any, set all of them to False, so there is a unique number with `verified=True`,
+        # allow exactly single 'verified=True' value per 'number'
+        if self.verified:
+            UserPhoneNumber.objects.filter(number=self.number, verified=True).update(verified=False)
+
+            # if current owner still does not have any default number (first time a number is saved),
+            # this under verified if statement since only verified number should be able default.
+            if not UserPhoneNumber.objects.filter(owner=self.owner, is_default=True):
+                self.is_default = True
+
+        # check are no multiple numbers, for the same owner (user) which are `is_default=True`,
+        # if there are any, set all of them to False, so there is a unique number (per user) with `is_default=True`.
+        # allow exactly single 'is_default=True' value per 'owner'
+        if self.is_default:
+            UserPhoneNumber.objects.filter(owner=self.owner, is_default=True).update(is_default=False)
+
+        # save new verified state to __original_verified for future checks
+        self.__original_verified = self.verified
+        super(UserPhoneNumber, self).save(*args, **kwargs)
 
     def __str__(self):
         return str(self.number)
@@ -164,10 +197,10 @@ class UserManager(BaseUserManager):
 
 
 class User(AbstractBaseUser, PermissionsMixin):
-    email = models.EmailField(unique=True, primary_key=True)
+    email = models.EmailField(unique=True, primary_key=True, validators=[validate_email])
     user_name = models.CharField(_('User Name'), max_length=128, blank=True)
-    first_name = models.CharField(_('First Name'), max_length=32, blank=True)
-    last_name = models.CharField(_('Last Name'), max_length=32, blank=True)
+    first_name = models.CharField(_('First Name'), max_length=32, blank=True, validators=[validate_alphabetic_string])
+    last_name = models.CharField(_('Last Name'), max_length=32, blank=True, validators=[validate_alphabetic_string])
 
     address = models.ManyToManyField(Address, verbose_name=_('Address'))
 
@@ -178,8 +211,6 @@ class User(AbstractBaseUser, PermissionsMixin):
     )
     gender = models.CharField(_('Gender'), choices=USER_GENDER_CHOICES, max_length=1, default='x')
     birth_date = models.DateField(_('Birth Date'), null=True, blank=True, validators=[validate_users_min_age])
-    default_phone_number = models.OneToOneField(PhoneNumber, on_delete=models.CASCADE,
-                                                null=True, blank=True, verbose_name=_('Default Contact Number'))
 
     linkedin = models.URLField(max_length=255, blank=True)
     facebook = models.URLField(max_length=255, blank=True)
@@ -199,9 +230,9 @@ class User(AbstractBaseUser, PermissionsMixin):
         default=False,
         help_text=_('Define if this user should be treated as active. '),
     )
-    date_created = models.DateTimeField(_('Date Created'), auto_now_add=True, blank=True)
-    last_update_date = models.DateTimeField(auto_now=True)
-    last_login = models.DateTimeField(default=None, blank=True, null=True)
+    date_created = models.DateTimeField(_('Date Created'), auto_now_add=True, blank=True, editable=False)
+    last_update_date = models.DateTimeField(auto_now=True, editable=False)
+    last_login = models.DateTimeField(default=None, blank=True, null=True, editable=False)
     last_login_ip = models.GenericIPAddressField(_('Logged in from'), default=None, blank=True, null=True)
 
     objects = UserManager()
